# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.organizations_v1_api import OrganizationsV1Api


class TestOrganizationsV1Api(unittest.TestCase):
    """OrganizationsV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = OrganizationsV1Api()

    def tearDown(self) -> None:
        pass

    def test_delete_organization(self) -> None:
        """Test case for delete_organization

        Delete Organization.
        """
        pass

    def test_get_users_organization(self) -> None:
        """Test case for get_users_organization

        Get Users Organization.
        """
        pass

    def test_patch_organization(self) -> None:
        """Test case for patch_organization

        Patch Organization.
        """
        pass


if __name__ == '__main__':
    unittest.main()
