# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.continuous_eval_response import ContinuousEvalResponse

class TestContinuousEvalResponse(unittest.TestCase):
    """ContinuousEvalResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ContinuousEvalResponse:
        """Test ContinuousEvalResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ContinuousEvalResponse`
        """
        model = ContinuousEvalResponse()
        if include_optional:
            return ContinuousEvalResponse(
                id = '',
                name = '',
                description = '',
                task_id = '',
                llm_eval_name = '',
                llm_eval_version = 56,
                transform_id = '',
                transform_variable_mapping = [
                    arthur_client.api_bindings.models.continuous_eval_transform_variable_mapping_response.ContinuousEvalTransformVariableMappingResponse(
                        transform_variable = '', 
                        eval_variable = '', )
                    ],
                enabled = True,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return ContinuousEvalResponse(
                id = '',
                name = '',
                task_id = '',
                llm_eval_name = '',
                llm_eval_version = 56,
                transform_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testContinuousEvalResponse(self):
        """Test ContinuousEvalResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
