# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.unregistered_agent_response import UnregisteredAgentResponse

class TestUnregisteredAgentResponse(unittest.TestCase):
    """UnregisteredAgentResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UnregisteredAgentResponse:
        """Test UnregisteredAgentResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UnregisteredAgentResponse`
        """
        model = UnregisteredAgentResponse()
        if include_optional:
            return UnregisteredAgentResponse(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                name = '',
                creation_source = arthur_client.api_bindings.models.creation_source.CreationSource(
                    task_id = '', 
                    top_level_span_name = '', 
                    gcp_project_id = '', 
                    gcp_region = '', 
                    gcp_reasoning_engine_id = '', ),
                first_detected = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                num_spans = 56,
                infrastructure = 'AWS',
                data_plane_id = '',
                tools = [
                    arthur_client.api_bindings.models.tool_response.ToolResponse(
                        id = '', 
                        name = '', 
                        arguments = [
                            arthur_client.api_bindings.models.tool_argument_response.ToolArgumentResponse(
                                id = '', 
                                name = '', 
                                type = '', )
                            ], )
                    ],
                sub_agents = [
                    arthur_client.api_bindings.models.sub_agent_response.SubAgentResponse(
                        id = '', 
                        name = '', )
                    ],
                model_id = '',
                model_name = ''
            )
        else:
            return UnregisteredAgentResponse(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                name = '',
                creation_source = arthur_client.api_bindings.models.creation_source.CreationSource(
                    task_id = '', 
                    top_level_span_name = '', 
                    gcp_project_id = '', 
                    gcp_region = '', 
                    gcp_reasoning_engine_id = '', ),
                first_detected = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                infrastructure = 'AWS',
                data_plane_id = '',
        )
        """

    def testUnregisteredAgentResponse(self):
        """Test UnregisteredAgentResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
